@@ -4,6 +4,7 @@ from pathlib import Path
 
 import click
 import questionary
+import setproctitle
 from prompt_toolkit import PromptSession
 from prompt_toolkit.auto_suggest import AutoSuggestFromHistory
 from prompt_toolkit.completion import Completer, Completion
@@ -18,6 +19,7 @@ from .browser import ManualBrowser, run_agent_browser
 from .config import ConfigManager
 from .engineer import run_reverse_engineering
 from .messages import MessageStore
+from .playwright_codegen import PlaywrightCodeGenerator
 from .session import SessionManager
 from .tui import (
     ERROR_CTA,
@@ -30,6 +32,7 @@ from .tui import (
     get_model_choices,
 )
 from .utils import (
+    check_for_updates,
     generate_folder_name,
     generate_run_id,
     get_actions_path,
@@ -38,11 +41,10 @@ from .utils import (
     get_history_path,
     get_scripts_dir,
     get_timestamp,
+    parse_codegen_tag,
     parse_engineer_prompt,
     parse_record_only_tag,
-    parse_codegen_tag,
 )
-from .playwright_codegen import PlaywrightCodeGenerator
 
 console = Console()
 config_manager = ConfigManager(get_config_path())
@@ -344,6 +346,7 @@ def prompt_interactive_options(
 @click.version_option(version=__version__)
 def main(ctx: click.Context):
     """Reverse API - Capture browser traffic for API reverse engineering."""
+    setproctitle.setproctitle("reverse-api-engineer")
     if ctx.invoked_subcommand is None:
         repl_loop()
 
@@ -353,7 +356,7 @@ def repl_loop():
     # Get current SDK and model from config
     sdk = config_manager.get("sdk", "claude")
     if sdk == "opencode":
-        model = config_manager.get("opencode_model", "claude-sonnet-4-5")
+        model = config_manager.get("opencode_model", "claude-opus-4-5")
     else:
         model = config_manager.get("claude_code_model", "claude-sonnet-4-5")
 
@@ -361,6 +364,11 @@ def repl_loop():
     console.print("  [dim]shift+tab to cycle modes: manual | engineer | agent | collector[/dim]")
     display_footer(console)
 
+    # Check for updates
+    if update_msg := check_for_updates():
+        console.print(f"  [yellow]{update_msg}[/yellow]")
+        console.print()
+
     current_mode = "manual"
 
     while True:
@@ -683,10 +691,10 @@ def handle_settings(mode_color=THEME_PRIMARY):
                 console.print(f" [dim]updated[/dim] opencode provider: {new_provider}\n")
 
     elif action == "opencode_model":
-        current = config_manager.get("opencode_model", "claude-sonnet-4-5")
+        current = config_manager.get("opencode_model", "claude-opus-4-5")
         new_model = questionary.text(
             " > opencode model",
-            default=current or "claude-sonnet-4-5",
+            default=current or "claude-opus-4-5",
             instruction="(e.g., 'claude-sonnet-4-5', 'claude-opus-4-5')",
             qmark="",
             style=questionary.Style(
@@ -959,7 +967,9 @@ def handle_collector_help(mode_color=THEME_PRIMARY):
     table.add_column(style=f"{mode_color} bold", justify="left", width=30)
     table.add_column(style="white", justify="left")
 
-    table.add_row("<prompt>", "Describe data to collect in natural language.\n[dim]Example: Find 10 YC W24 AI startups with name, website, funding[/dim]")
+    table.add_row(
+        "<prompt>", "Describe data to collect in natural language.\n[dim]Example: Find 10 YC W24 AI startups with name, website, funding[/dim]"
+    )
     table.add_row("", "")
 
     table.add_row("Output", "JSON + CSV saved to ./collected/<folder>/")
@@ -1165,7 +1175,7 @@ def run_manual_capture(prompt=None, url=None, reverse_engineer=True, model=None,
     # Parse @record-only tag - if present, skip reverse engineering
     prompt, is_record_only = parse_record_only_tag(prompt)
     prompt, is_codegen = parse_codegen_tag(prompt)
-    
+
     if is_record_only:
         reverse_engineer = False
     if is_codegen:
@@ -1187,12 +1197,7 @@ def run_manual_capture(prompt=None, url=None, reverse_engineer=True, model=None,
         paths={"har_dir": str(get_har_dir(run_id, output_dir))},
     )
 
-    browser = ManualBrowser(
-        run_id=run_id, 
-        prompt=prompt, 
-        output_dir=output_dir,
-        enable_action_recording=is_codegen
-    )
+    browser = ManualBrowser(run_id=run_id, prompt=prompt, output_dir=output_dir, enable_action_recording=is_codegen)
     har_path = browser.start(start_url=url)
 
     if reverse_engineer:
@@ -1454,7 +1459,7 @@ def run_auto_capture(prompt=None, url=None, model=None, output_dir=None):
                 prompt=prompt,
                 output_dir=output_dir,
                 opencode_provider=config_manager.get("opencode_provider", "anthropic"),
-                opencode_model=config_manager.get("opencode_model", "claude-sonnet-4-5"),
+                opencode_model=config_manager.get("opencode_model", "claude-opus-4-5"),
                 enable_sync=config_manager.get("real_time_sync", False),
                 sdk=sdk,
                 output_language=output_language,
@@ -1500,33 +1505,28 @@ def run_auto_capture(prompt=None, url=None, model=None, output_dir=None):
         return None
 
 
-def run_playwright_codegen(
-    run_id: str, 
-    prompt: str, 
-    output_dir: str | None = None,
-    start_url: str | None = None
-):
+def run_playwright_codegen(run_id: str, prompt: str, output_dir: str | None = None, start_url: str | None = None):
     """Generate Playwright script from recorded actions."""
     actions_path = get_actions_path(run_id, output_dir)
     if not actions_path.exists():
         console.print(" [red]error:[/red] no actions recorded")
         return
-    
+
     from .action_recorder import ActionRecorder
-    
+
     actions = ActionRecorder.load(actions_path)
     action_list = actions.get_actions()
-    
+
     # If no explicit start_url, extract from first navigate action
     if not start_url and action_list:
         if action_list[0].type == "navigate" and action_list[0].url:
             start_url = action_list[0].url
-    
+
     generator = PlaywrightCodeGenerator(action_list, start_url=start_url)
     script = generator.generate()
-    
+
     scripts_dir = get_scripts_dir(run_id, output_dir)
-    
+
     # Handle duplicate file paths
     script_path = scripts_dir / "automation.py"
     if script_path.exists():
@@ -1534,12 +1534,12 @@ def run_playwright_codegen(
         while (scripts_dir / f"automation_{i}.py").exists():
             i += 1
         script_path = scripts_dir / f"automation_{i}.py"
-    
+
     script_path.write_text(script)
-    
+
     # Also write requirements.txt
     (scripts_dir / "requirements.txt").write_text("playwright\n")
-    
+
     console.print(" [dim]>[/dim] [white]codegen complete[/white]")
     console.print(f" [dim]>[/dim] [white]{script_path}[/white]")
     console.print(f" [dim]>[/dim] [dim]run with: uv run python {script_path}[/dim]\n")
@@ -1603,7 +1603,7 @@ def run_engineer(
             output_dir=output_dir,
             sdk=sdk,
             opencode_provider=config_manager.get("opencode_provider", "anthropic"),
-            opencode_model=config_manager.get("opencode_model", "claude-sonnet-4-5"),
+            opencode_model=config_manager.get("opencode_model", "claude-opus-4-5"),
             enable_sync=enable_sync,
             additional_instructions=additional_instructions,
             is_fresh=is_fresh,
@@ -1677,5 +1677,44 @@ def run_engineer(
     return result
 
 
+@main.command("install-host")
+@click.option(
+    "--extension-id",
+    default=None,
+    help="Chrome extension ID (required - get from chrome://extensions/)",
+)
+def install_host(extension_id: str | None):
+    """Install the native messaging host for Chrome extension integration."""
+    from .native_host import install_native_host
+
+    success, message = install_native_host(extension_id)
+    if success:
+        console.print(f"[green]{message}[/green]")
+    else:
+        console.print(f"[red]{message}[/red]")
+        raise SystemExit(1)
+
+
+@main.command("uninstall-host")
+def uninstall_host():
+    """Uninstall the native messaging host."""
+    from .native_host import uninstall_native_host
+
+    success, message = uninstall_native_host()
+    if success:
+        console.print(f"[green]{message}[/green]")
+    else:
+        console.print(f"[red]{message}[/red]")
+        raise SystemExit(1)
+
+
+@main.command("run-host")
+def run_host_cmd():
+    """Run the native messaging host (used by Chrome extension)."""
+    from .native_host import run_host
+
+    run_host()
+
+
 if __name__ == "__main__":
     main()
