@@ -27,6 +27,75 @@ def debug_log(msg: str):
         print(f"[{ts}] [DEBUG] {msg}")
 
 
+def format_error(e: Exception) -> str:
+    """Format exception with full details in a pretty, readable format."""
+    error_type = type(e).__name__
+    error_msg = str(e)
+
+    # Build comprehensive error message with pretty formatting
+    lines = []
+
+    # Main error line - always show error type and message
+    if error_msg:
+        lines.append(f"[bold red]✗ {error_type}[/bold red]")
+        lines.append(f"  {error_msg}")
+    else:
+        lines.append(f"[bold red]✗ {error_type}[/bold red] (no message)")
+
+    # Add additional context for specific exception types
+    if isinstance(e, httpx.HTTPStatusError):
+        if hasattr(e, "response") and e.response is not None:
+            try:
+                status_code = e.response.status_code
+                status_text = e.response.reason_phrase or "Unknown"
+                lines.append(f"\n[dim]HTTP Status:[/dim] [yellow]{status_code}[/yellow] {status_text}")
+
+                # Try to parse JSON response for better formatting
+                try:
+                    response_json = e.response.json()
+                    import json
+
+                    response_text = json.dumps(response_json, indent=2)[:1000]  # Limit to 1000 chars
+                    lines.append(f"\n[dim]Response Body:[/dim]")
+                    # Split into lines and indent
+                    for line in response_text.split("\n"):
+                        lines.append(f"  [dim]{line}[/dim]")
+                except Exception:
+                    # Fall back to text if not JSON
+                    response_text = e.response.text[:500]
+                    if response_text:
+                        lines.append(f"\n[dim]Response Body:[/dim]")
+                        lines.append(f"  [dim]{response_text}[/dim]")
+            except Exception:
+                pass
+
+    elif isinstance(e, httpx.ConnectError):
+        lines.append(f"\n[dim]Unable to connect to OpenCode server[/dim]")
+        if error_msg and "Connection refused" not in error_msg:
+            lines.append(f"  [dim]{error_msg}[/dim]")
+
+    elif isinstance(e, httpx.ReadError):
+        lines.append(f"\n[dim]Connection was interrupted while reading response[/dim]")
+        if error_msg:
+            lines.append(f"  [dim]{error_msg}[/dim]")
+
+    elif isinstance(e, httpx.TimeoutException):
+        lines.append(f"\n[dim]Request timed out[/dim]")
+        if error_msg:
+            lines.append(f"  [dim]{error_msg}[/dim]")
+
+    # In debug mode, include traceback
+    if DEBUG:
+        import traceback
+
+        tb_str = "".join(traceback.format_exception(type(e), e, e.__traceback__))
+        lines.append(f"\n[dim]Traceback:[/dim]")
+        for line in tb_str.split("\n"):
+            lines.append(f"  [dim]{line}[/dim]")
+
+    return "\n".join(lines)
+
+
 class OpenCodeEngineer(BaseEngineer):
     """Uses OpenCode AI to analyze HAR files and generate Python API scripts."""
 
@@ -42,7 +111,7 @@ class OpenCodeEngineer(BaseEngineer):
     def __init__(self, *args, **kwargs):
         # Pop OpenCode-specific kwargs before passing to parent class
         self.opencode_provider = kwargs.pop("opencode_provider", "anthropic")
-        self.opencode_model = kwargs.pop("opencode_model", "claude-sonnet-4-5")
+        self.opencode_model = kwargs.pop("opencode_model", "claude-opus-4-5")
 
         super().__init__(*args, **kwargs)
 
@@ -53,6 +122,16 @@ class OpenCodeEngineer(BaseEngineer):
         self._session_id: str | None = None
         self._last_event_time = 0.0
 
+        # Read OpenCode server authentication from environment variables
+        self.opencode_password = os.environ.get("OPENCODE_SERVER_PASSWORD")
+        self.opencode_username = os.environ.get("OPENCODE_SERVER_USERNAME", "opencode")
+
+    def _get_auth(self) -> httpx.BasicAuth | None:
+        """Get HTTP Basic Auth object if password is configured."""
+        if self.opencode_password:
+            return httpx.BasicAuth(self.opencode_username, self.opencode_password)
+        return None
+
     async def analyze_and_generate(self) -> dict[str, Any] | None:
         """Run the reverse engineering analysis with OpenCode."""
         self.opencode_ui.header(self.run_id, self.prompt, self.opencode_model, self.sdk)
@@ -62,16 +141,27 @@ class OpenCodeEngineer(BaseEngineer):
         self.message_store.save_prompt(self._build_analysis_prompt())
 
         try:
-            async with httpx.AsyncClient(base_url=self.BASE_URL, timeout=600.0) as client:
+            auth = self._get_auth()
+            async with httpx.AsyncClient(base_url=self.BASE_URL, timeout=600.0, auth=auth) as client:
                 # Health check
                 try:
                     health_r = await client.get("/global/health")
                     health_r.raise_for_status()
                     health = health_r.json()
                     self.opencode_ui.health_check(health)
+                except httpx.HTTPStatusError as e:
+                    if e.response.status_code == 401:
+                        debug_log(f"Health check failed: Authentication required")
+                        self.opencode_ui.error("Authentication failed. OpenCode server requires a password.")
+                        self.opencode_ui.console.print("\n[dim]Please set OPENCODE_SERVER_PASSWORD environment variable[/dim]")
+                        if self.opencode_username != "opencode":
+                            self.opencode_ui.console.print(f"[dim]Username: {self.opencode_username}[/dim]")
+                        return None
+                    raise
                 except Exception as e:
                     debug_log(f"Health check failed: {e}")
                     self.opencode_ui.error(f"OpenCode server not responding. Is it running on {self.BASE_URL}?")
+                    self.opencode_ui.console.print("\n[dim]Please run: opencode serve[/dim]")
                     return None
 
                 # Create a new session
@@ -125,7 +215,8 @@ class OpenCodeEngineer(BaseEngineer):
 
             # Fetch actual provider and model used from session messages
             try:
-                async with httpx.AsyncClient(base_url=self.BASE_URL, timeout=10.0) as client:
+                auth = self._get_auth()
+                async with httpx.AsyncClient(base_url=self.BASE_URL, timeout=10.0, auth=auth) as client:
                     messages_r = await client.get(f"/session/{self._session_id}/message")
                     if messages_r.status_code == 200:
                         messages = messages_r.json()
@@ -139,7 +230,9 @@ class OpenCodeEngineer(BaseEngineer):
                                     self.opencode_ui.model_info(provider_id, model_id)
                                     break
             except Exception as e:
-                debug_log(f"Failed to fetch session messages: {e}")
+                error_msg = format_error(e)
+                debug_log(f"Failed to fetch session messages: {error_msg}")
+                # Don't fail the whole operation if we can't fetch messages
 
             # Show session summary before success message
             self.opencode_ui.session_summary(self.usage_metadata)
@@ -154,14 +247,33 @@ class OpenCodeEngineer(BaseEngineer):
             self.message_store.save_result(result_data)
             return result_data
 
-        except httpx.ConnectError:
+        except httpx.HTTPStatusError as e:
+            if e.response.status_code == 401:
+                self.opencode_ui.error("Authentication failed. OpenCode server requires a password.")
+                self.opencode_ui.console.print("\n[dim]Please set OPENCODE_SERVER_PASSWORD environment variable[/dim]")
+                if self.opencode_username != "opencode":
+                    self.opencode_ui.console.print(f"[dim]Username: {self.opencode_username}[/dim]")
+                self.message_store.save_error("Authentication failed")
+                return None
+            # Show detailed error including response body
+            error_msg = format_error(e)
+            debug_log(f"HTTPStatusError in analyze_and_generate: {error_msg}")
+            self.opencode_ui.error(error_msg)
+            self.message_store.save_error(error_msg)
+            return None
+
+        except httpx.ConnectError as e:
+            error_msg = format_error(e)
+            debug_log(f"ConnectError in analyze_and_generate: {error_msg}")
             self.opencode_ui.error("Connection error")
-            self.opencode_ui.console.print("\n[dim]Make sure OpenCode is running: opencode[/dim]")
-            self.message_store.save_error("Connection error")
+            self.opencode_ui.console.print(f"\n[dim]Details: {error_msg}[/dim]")
+            self.opencode_ui.console.print("\n[dim]Please run: opencode serve[/dim]")
+            self.message_store.save_error(f"Connection error: {error_msg}")
             return None
 
         except Exception as e:
-            error_msg = str(e) if str(e) else "Unknown error"
+            error_msg = format_error(e)
+            debug_log(f"Exception in analyze_and_generate: {error_msg}")
             self.opencode_ui.error(error_msg)
             self.message_store.save_error(error_msg)
             return None
@@ -341,9 +453,11 @@ class OpenCodeEngineer(BaseEngineer):
                         return
 
         except httpx.ReadError as e:
-            self._last_error = f"Stream disconnected: {e}"
+            self._last_error = format_error(e)
+            debug_log(f"ReadError in _stream_events: {self._last_error}")
         except Exception as e:
-            self._last_error = str(e) if str(e) else "Stream error"
+            self._last_error = format_error(e)
+            debug_log(f"Exception in _stream_events: {self._last_error}")
 
     async def _handle_part_update(self, properties: dict, seen_parts: set):
         """Handle message.part.updated events."""
